import React, { useEffect, useRef, useState } from 'react';
import { history, useParams, useRequest } from 'umi';
import { ModalForm, ProFormInstance } from '@ant-design/pro-form';
import { ProFormRadio } from '@ant-design/pro-form';
import ProForm, {
    StepsForm,
    ProFormText,
    ProFormDatePicker,
    ProFormSelect,
    ProFormTextArea,
    ProFormCheckbox,
    ProFormDateRangePicker,
} from '@ant-design/pro-form';
import ProCard from '@ant-design/pro-card';
import { Button, Checkbox, Col, Divider, Dropdown, Form, Input, List, Menu, message, Modal, Radio, Row, Space, Table, Typography, Upload } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import ProDescriptions from '@ant-design/pro-descriptions';
import styles from './index.less'
import { saveRules, querySubjectList, queryRulesView, queryTempQuestionList, saveQuestionTypeScore } from '../../service';
import { queryCourseView } from '@/pages/course/option/service';
import { queryQuestionList, queryQuestionById, queryQuestionType } from '@/pages/questionbank/service';
import { PlusOutlined, DownOutlined, DeleteOutlined, DownloadOutlined, UploadOutlined, EyeInvisibleOutlined, EyeOutlined, EditOutlined } from '@ant-design/icons';
import ProList from '@ant-design/pro-list';

import { autoPaper, manualPaper, updatePaper } from '../service';
import ProTable, { EditableProTable } from '@ant-design/pro-table';

import QuestionSelector from '../../components/QuestionSelector';
import ScoreSetter from '../../components/ScoreSetter';
import AutoSelector from '../components/AutoSelector';

/**
 * 保存选题
 *
 * @param values
 */
const handleAppend = async (rules_id: number, rows: any[]) => {
    const hide = message.loading('正在添加');
    try {
        const questions: { question_id: any; }[] = [];
        rows?.forEach((item)=>{
            questions.push({question_id: item?.id})
        })
        const _data = await manualPaper({ 
            question_count: questions?.length || 0, 
            questions: JSON.stringify(questions),
            rules_id: Number(rules_id)
        });
        hide();
        message.success('添加成功');
        return _data;
    } catch (error) {
        hide();
        message.error('添加失败请重试！');
        return false;
    }
};

/**
 * 保存选题试卷
 *
 * @param values
 */
 const handleUpdatePaper = async ( rules_id: number, paper_uuid: number, paper_id: number) => {
    const hide = message.loading('正在保存');
    try {
        const _data = {
            rules_id: Number(rules_id), 
            paper_uuid: paper_uuid, 
            paper_id: paper_id
        }
        if(paper_id === 0){
            delete _data.paper_id;
        }
        await updatePaper(_data);
        hide();
        message.success('保存成功');
        return true;
    } catch (error) {
        hide();
        message.error('保存失败请重试！');
        return false;
    }
};

const waitTime = (time: number = 100) => {
    return new Promise((resolve) => {
        setTimeout(() => {
            resolve(true);
        }, time);
    });
};

// 模拟考试规则维护
export default () => {
    
    const [selectorModalVisible, handleSelectorModalVisible] = useState<boolean>(false);
    const [scoreModalVisible, handleScoreModalVisible] = useState<boolean>(false);
    const [autoModalVisible, handleAutoModalVisible] = useState<boolean>(false);    

    const [subjectId, setSubjectId] = useState<number>(0); // 关联主题id
    const [uuidPaper, setUuidPaper] = useState<number>(0);
    const [createType, setCreateType] = useState<number>(1); // 组卷类型
    const [rulesName, setRulesName] = useState<string>(''); // 组卷类型
    

    const formRef = useRef<ProFormInstance>();

    const selectorRef = useRef();
    const setterRef = useRef();
    const autoRef = useRef();    

    const params = useParams();
    
    const [questionType, setQuestionType] = useState([]); // 题型
    const [scoreValues, SetscoreValues] = useState([]); // 分值 [{"question_type": "0","score": "3","score_harf": "0"},]
    
    /** 获取题型 */
    const { data: questionTypeData } = useRequest(() => {
        return queryQuestionType();
    },{
        formatResult: (result) => {
        return result.list;
        }
    });

    useEffect(() => {
        setQuestionType(questionTypeData || []);
        return ()=>{
          /** 退出当前页面清空Map */
          //parsingMap.clear();
        }
    }, [questionTypeData]);
    
    /** 组卷，查询试题临时表（当前选题列表） */
    const { data: questions, run } = useRequest(async () => {
        return queryTempQuestionList(params);
    },{
        manual: true,
        formatResult: (result) => {
        return result?.bean;
    }});

    console.log(params, 'params');

    let ruleData = {}
    if (params?.id) {
        //console.log(JSON.stringify(params), "878");
        const { data } = useRequest(async () => {
            return queryRulesView(params);
        },{
            formatResult: (result) => {
            return result?.bean;
        }});
        ruleData = data
    }
    console.log(ruleData, 'ruleData');

    return (
        <PageContainer content={''} extraContent={''}>
            <ProCard className={styles.examinationrules}>
                <StepsForm<{
                    name: string;
                }>
                    formRef={formRef}
                    onFinish={async (e) => {
                        message.success('提交成功');
                    }}
                    formProps={{
                        layout: "horizontal",
                        labelCol: { span: 8 },
                        wrapperCol: { span: 12 },
                        validateMessages: {
                            required: '此项为必填项',
                        },
                    }}
                >
                    <StepsForm.StepForm<{
                        name: string;
                    }>
                        name="base"
                        title="模拟考试基本信息"
                        stepProps={{
                            description: false,
                        }}
                        onFinish={async (fileds) => {
                            if (params?.id) {
                                fileds = { ...fileds, id: params.id }
                            }
                            console.log(fileds, 'fileds', params);

                            await saveRules({
                                ...fileds,
                                b_use: 0,
                                rules_type: 0,
                            });
                            run({paper_uuid:1}); // 获取当前选题列表
                            // console.log('模拟考试基本信息', fileds)
                            setSubjectId(fileds?.subject_id) // 设置当前关联主题
                            setRulesName(fileds?.rules_name) // 设置模拟考试规则名称
                            
                            // await waitTime(2000);
                            return true;

                        }}
                    >
                        <Row gutter={24}>
                            <Col lg={24} md={24} sm={24}>
                                {ruleData && (
                                    <>
                                        <ProFormText
                                            name="rules_name"
                                            label="考试名称"
                                            width="md"
                                            initialValue={ruleData?.rules_name}
                                            // tooltip="最长为 6 位汉字，需要与考生身份证一致"
                                            placeholder="请输入名称"
                                            rules={[{ required: true, message: '请输入考试名称' }]}
                                            // value="锦书"
                                            // disabled
                                        />

                                        <ProFormSelect
                                            width="md"
                                            initialValue={ruleData?.subject_id}
                                            request={async () => {
                                                return querySubjectList().then(({ data }) => {
                                                    console.log(data, 'querySubjectList')
                                                    return data.list.map((item) => {
                                                        return {
                                                            label: item?.subject_name,
                                                            value: item?.subject_id,
                                                        };
                                                    });
                                                });
                                            }}
                                            rules={[{ required: true, message: '请选择主题' }]}
                                            name="subject_id"
                                            label="关联主题"
                                        />
                                        <ProFormText name="examination_time" label="考试时长"
                                            width="md"
                                            initialValue={ruleData?.examination_time}
                                            rules={[{ required: true, message: '请输入考试时长' }]}
                                            tooltip="限制考试时长的情况下，用户考试中离开，倒计时不会停止。" />
                                    </>
                                )}
                            </Col>
                        </Row>

                    </StepsForm.StepForm>

                    <StepsForm.StepForm<{
                        checkbox: string;
                    }>
                        name="object"
                        title="组卷"
                        stepProps={{
                            description: false,
                        }}
                        onFinish={async () => {
                            console.log(formRef.current?.getFieldsValue());
                            return true;
                        }}
                    >
                        <div style={{ margin: '0' }}>
                            <Typography style={{ padding: 24, fontSize: 24, textAlign: 'center' }}>{rulesName}</Typography>
                            {/** 一旦录入另一项将禁用，清空组卷后可选另一项 */}
                            <Radio.Group size='large'  value={createType} onChange={(e) => {
                                setCreateType(Number(e?.target?.value))
                                console.log('value', e?.target?.value)
                                //handleAutoModalVisible(true); // 显示系统组卷窗口
                            }} style={{ marginBottom: 16, }}>
                                <Radio.Button value={1} style={{width:200, textAlign:'center'}}>手动组卷</Radio.Button>
                                <Radio.Button value={2} style={{width:200, textAlign:'center'}}>系统组卷</Radio.Button>
                            </Radio.Group>
                            <Divider style={{ margin: '6px 0', opacity: 0.5 }} />
                            <Row>
                                <Col span={18} style={{ background: '#ffffff', padding: 0 }}>
                                    <ProCard
                                        title="一. 单选题 （共50分，每题1分）"
                                        extra={false}
                                        split='vertical'
                                        bordered
                                        headerBordered
                                    >
                                        <Space direction="vertical" style={{ width: '100%', padding: '24px 48px' }}>

                                            <Typography style={{ marginBottom: 16, fontSize: 18 }}>
                                                4. 以下哪些是符合法律规定的 ？
                                            </Typography>
                                            <Radio.Group onChange={() => { return true }} value={0} size="large">
                                                <Space direction="vertical" style={{ fontSize: 16 }}>
                                                    <Radio value={1} style={{ padding: 5, fontSize: 16 }}>A. 单位在试用期辞退员工</Radio>
                                                    <Radio value={2} style={{ padding: 5, fontSize: 16 }}>B. 社会中介收取中介费</Radio>
                                                    <Radio value={3} style={{ padding: 5, fontSize: 16 }}>C. 单位不缴纳五险一金</Radio>
                                                    <Radio value={4} style={{ padding: 5, fontSize: 16 }}>D. 要求员工支付押金</Radio>
                                                </Space>
                                            </Radio.Group>

                                            <Typography style={{ marginBottom: 16, fontSize: 18 }}>
                                                5. 以下哪些是不符合法律规定的(多选) ？
                                            </Typography>
                                            <Checkbox.Group onChange={() => { return true }}>
                                                <Space direction="vertical" style={{}}>
                                                    <Checkbox value={1} style={{ padding: 5, fontSize: 16 }}>A. 单位在试用期辞退员工</Checkbox>
                                                    <Checkbox value={2} style={{ padding: 5, fontSize: 16 }}>B. 社会中介收取中介费</Checkbox>
                                                    <Checkbox value={3} style={{ padding: 5, fontSize: 16 }}>C. 单位不缴纳五险一金</Checkbox>
                                                    <Checkbox value={4} style={{ padding: 5, fontSize: 16 }}>D. 要求员工支付押金</Checkbox>
                                                </Space>
                                            </Checkbox.Group>

                                            <Typography style={{ marginBottom: 16, fontSize: 18 }}>
                                                6. 单位在试用期辞退员工是符合法律规定的 ？
                                            </Typography>
                                            <Radio.Group onChange={() => { return true }} value={0} size="large">
                                                <Space direction="vertical" style={{ fontSize: 16 }}>
                                                    <Radio value={1} style={{ padding: 5, fontSize: 16 }}>正确</Radio>
                                                    <Radio value={2} style={{ padding: 5, fontSize: 16 }}>错误</Radio>
                                                </Space>
                                            </Radio.Group>
                                        </Space>
                                    </ProCard>
                                </Col>
                                <Col span={6} style={{ paddingLeft: 24 }}>
                                    <div style={{ background: '#ffffff', padding: 24 }}>
                                        <Space direction="vertical" style={{ width: '100%' }}>
                                            <strong>试卷信息与设置</strong>
                                            <Typography>共 { 0 } 题 { 0 } 分</Typography>
                                            <Divider style={{ margin: '6px 0', opacity: 0.5 }} />
                                            <Space direction="vertical">
                                            {   questionType.map((item)=>{
                                                    return <Typography>{item?.name} 共 { 0 } 题 { 0 } 分</Typography>
                                                }
                                            )}
                                            </Space>
                                            <Divider style={{ margin: '6px 0', opacity: 0.5 }} />

                                            <Button size="large" block onClick={()=>{
                                                console.log('createType', createType)
                                                if(createType === 1){
                                                    console.log('11:',createType)
                                                    handleSelectorModalVisible(true)
                                                }else{
                                                    console.log('22:',createType)
                                                    handleAutoModalVisible(true); // 显示系统组卷窗口(true)
                                                }
                                                
                                            }}>选择试题</Button>

                                            <Button size="large" block onClick={()=>{
                                                handleScoreModalVisible(true)
                                            }}>批量设置分值</Button>
                                            <Button size="large" type="primary" block onClick={async ()=>{
                                                console.log('uuidPaper::', uuidPaper)
                                                console.log('rules_id::', params?.id)
                                                const paper_id = paper_id ? paper_id : 0;
                                                await handleUpdatePaper(params?.id, uuidPaper, paper_id)
                                            }}>保存试卷</Button>
                                        </Space>
                                    </div>
                                </Col>
                            </Row>
                        </div>
                    </StepsForm.StepForm>

                    <StepsForm.StepForm
                        name="time"
                        title="完成"
                        stepProps={{
                            description: false,
                        }}
                        onFinish={async () => {
                            console.log(formRef.current?.getFieldsValue());
                            // 跳转到指定路由
                            history.push('/examinationrules/normal');
                            return true;
                        }}
                    >

                        <Row gutter={24}>
                            <Col lg={12} md={12} sm={12} offset={8}>
                                <ProDescriptions
                                    layout='horizontal'
                                    column={1}
                                    //actionRef={actionRef}
                                    title="模拟考试"
                                    request={async () => {
                                        return Promise.resolve({
                                            success: true,
                                            data: { id: '这是一段文本', object: '', date: '2020-07-30 08:00', duration: '', grade: 100, through: '>60', learn: '>20 min', times: 2 },
                                        });
                                    }}
                                    extra={false}
                                >
                                    <ProDescriptions.Item dataIndex="id" hideInDescriptions />
                                    <ProDescriptions.Item dataIndex="object" label="考试名称" valueType="text" />
                                    <ProDescriptions.Item dataIndex="date" label="关联培训主题" valueType="text" />
                                    <ProDescriptions.Item dataIndex="duration" label="考试时长" valueType="money" />

                                    <ProDescriptions.Item dataIndex="grade" label="考试信息" valueType="text" />

                                    <ProDescriptions.Item dataIndex="through" label="通过标准" valueType="text" />
                                    <ProDescriptions.Item dataIndex="times" label="考试次数" valueType="text" />
                                </ProDescriptions>
                            </Col>
                        </Row>
                    </StepsForm.StepForm>
                </StepsForm>
            </ProCard>
            
            <ModalForm
                title={`手动组卷`}
                //
                width="60%"
                visible={selectorModalVisible}
                onVisibleChange={handleSelectorModalVisible}
                footer={null}
                onFinish={async (values) => {
                    
                    console.log('v::::', values.name);
                    const rows = selectorRef?.current?.getSelectedRows()
                    console.log('rows::::', rows);
                    const {code, data: paper, msg} = await handleAppend(Number(params?.id), rows)
                    console.log('paper', paper)
                    setUuidPaper(paper?.paper_uuid)
                    // message.success('提交成功');
                    handleSelectorModalVisible(false)
                    return true;
                }}
            >
                {selectorModalVisible && <QuestionSelector ref={selectorRef} />}
            </ModalForm>
            <ModalForm
                title={`系统组卷`}
                //
                width="60%"
                visible={autoModalVisible}
                onVisibleChange={ handleAutoModalVisible }
                footer={null}
                onFinish={async () => {                    
                    const values = autoRef?.current?.getData()
                    const {code, data: paper, msg} = await autoPaper({rules_id: Number(params?.id), auto_param: JSON.stringify(values)})
                    console.log('paper', paper)
                    //setUuidPaper(paper?.paper_uuid)
                    // message.success('提交成功');
                    handleAutoModalVisible(false)
                    return true;
                }}
            >
                {autoModalVisible && <AutoSelector ref={autoRef} subjectId={subjectId} questionType={questionType} />}
            </ModalForm>
            <ModalForm
                title={`批量设置分值`}
                //
                width="60%"
                visible={scoreModalVisible}
                onVisibleChange={handleScoreModalVisible}
                footer={null}
                onFinish={async () => {                    
                    const values = setterRef.current?.getData()                 
                    console.log('批量设置分值v::::', values);

                    const {code, data: paper, msg} = await saveQuestionTypeScore({rules_id:Number(params?.id), type_score: JSON.stringify(values)})
                    console.log('paper', paper)
                    // setUuidPaper(paper?.paper_uuid)
                    // message.success('提交成功');
                    handleScoreModalVisible(false)
                    return true;
                }}
            >
                <ScoreSetter ref={setterRef} />                
            </ModalForm>
        </PageContainer>

    );
};