import { PlusOutlined } from '@ant-design/icons';
import { Button, Card, List, Progress, Typography, Image } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import { history } from 'umi';
import { getRulesList } from './service';
import React, { useRef } from 'react';
import styles from './style.less';

import ProTable from '@ant-design/pro-table';

const columns: ProColumns<GithubIssueItem>[] = [
  {
    dataIndex: 'index',
    valueType: 'indexBorder',
    width: 48,
  },
  {
    title: '标题',
    dataIndex: 'rules_name',
  },

  {
    title: '考试时间',
    key: 'examination_time',
    dataIndex: 'examination_time',
    valueType: 'text',
  },
  {
    title: '总分',
    key: 'sum_score',
    dataIndex: 'sum_score',
    valueType: 'text',
  },
  {
    title: '及格',
    key: 'pass_score',
    dataIndex: 'pass_score',
    valueType: 'text',
  },

  {
    title: '操作',
    valueType: 'option',
    render: (text, record, _, action) => [
      <a
        key="editable"
        onClick={() => {
          history.push(`/mockExamination/paper/${record.id}`);
        }}
      >
        开始考试
      </a>,

    ],
  },
];
const SubjectList = () => {

  const actionRef = useRef<ActionType>();
  return (
    <PageContainer content={false} extraContent={false}>
      <div className={styles.cardList}>
        <ProTable<GithubIssueItem>
          columns={columns}
          actionRef={actionRef}
          request={async (value) => {
            const RulesData = await getRulesList({
              ...value,
              b_use: 1,
              rules_type: 0
            })
            console.log(RulesData.table_List)
            return { data: RulesData.table_List }
          }}
          editable={{
            type: 'multiple',
          }}
          columnsState={{
            persistenceKey: 'pro-table-singe-demos',
            persistenceType: 'localStorage',
          }}
          search={false}
          rowKey="id"
          toolBarRender={false}
          pagination={{
            pageSize: 10,
          }}
          dateFormatter="string"
          headerTitle="高级表格"
        />
      </div>
    </PageContainer>
  );
};

export default SubjectList;
